@@ -15,6 +15,7 @@
 using namespace ipmsg;
 
 #define HOST_LIST_SEND_MAX_AT_ONCE	100
+#define NULL_HARDWARE_ADDRESS		"00:00:00:00:00:00"
 
 /**
  * 󥹥ȥ饯
@@ -25,6 +26,7 @@ using namespace ipmsg;
 HostList::HostList()
 {
 	IPMSG_FUNC_ENTER( "HostList::HostList()" );
+	setIsAsking( false );
 	IpMsgMutexInit( "HostList::HostList()", &hostListMutex, NULL );
 	IPMSG_FUNC_EXIT;
 }
@@ -42,6 +44,7 @@ HostList::HostList( const HostList& other )
 	IpMsgMutexInit( "HostList::HostList(HostList&)", &hostListMutex, NULL );
 	Lock( "HostList::HostList(HostList&)" );
 	CopyFrom( other );
+	setIsAsking( false );
 	Unlock( "HostList::HostList(HostList&)" );
 	IPMSG_FUNC_EXIT;
 }
@@ -201,13 +204,15 @@ HostListItem::IsLocalHost() const
 	for( unsigned int i = 0; i < nics.size(); i++ ){
 		if ( IpAddress() == nics[i].IpAddress() ){
 #if defined(INFO) || !defined(NDEBUG)
-			printf("LOCALHOST\n");fflush(stdout);
+			printf("HostListItem::IsLocalHost This host item is localhost.\n");
+			fflush(stdout);
 #endif
 			IPMSG_FUNC_RETURN( true );
 		}
 	}
 #if defined(INFO) || !defined(NDEBUG)
-	printf("OTHERHOST\n");fflush(stdout);
+	printf("HostListItem::IsLocalHost This host item is not localhost.\n");
+	fflush(stdout);
 #endif
 	IPMSG_FUNC_RETURN( false );
 }
@@ -223,8 +228,18 @@ HostList::AddHost( const HostListItem& host, bool isPermitSameHardwareAddress )
 	IPMSG_FUNC_ENTER( "void HostList::AddHost( const HostListItem& host, bool isPermitSameHardwareAddress )" );
 	Lock( "HostList::AddHost()" );
 	bool is_found = false;
-//	isPermitSameHardwareAddress = true;
 
+#if defined(INFO) || !defined(NDEBUG)
+	printf("HostList::AddHost enter. host.IpAddress()=%s host.AddressFamily()=%s\n",
+							host.IpAddress().c_str(),
+							host.AddressFamily() == AF_INET6 ? "AF_INET6" : "AF_INET" );
+	fflush(stdout);
+#endif
+
+#if defined(INFO) || !defined(NDEBUG)
+	printf("HostList::AddHost Secondary NIC checking now.\n" );
+	fflush(stdout);
+#endif
 	IpMessengerAgentImpl *agent = IpMessengerAgentImpl::GetInstance();
 	std::string localhostName = agent->HostName();
 	std::vector<NetworkInterface> nics = agent->NICs;
@@ -246,39 +261,62 @@ HostList::AddHost( const HostListItem& host, bool isPermitSameHardwareAddress )
 	//õǥå֤饹
 	for( unsigned int i = nicStartIndex; i < nics.size(); i++ ){
 #if defined(INFO) || !defined(NDEBUG)
-		printf("AddHost HOST CHECK IpAddress=%s addr=%s\n", host.IpAddress().c_str(), nics[i].IpAddress().c_str() );fflush(stdout);
+		printf("HostList::AddHost now host checking IpAddress=%s NIC[%d] IpAddress=%s\n", host.IpAddress().c_str(), i, nics[i].IpAddress().c_str() );
+		fflush(stdout);
 #endif
 
 		if ( host.IpAddress() == nics[i].IpAddress() ) {
 #if defined(INFO) || !defined(NDEBUG)
-			printf("AddHost HOST MATCH\n" );fflush(stdout);
+			printf("HostList::AddHost Host IP Address is match secondary NIC IP Address\nIgnore this IP Address\n" );fflush(stdout);
+			fflush(stdout);
 #endif
 			Unlock( "HostList::AddHost()" );
 			IPMSG_FUNC_RETURN( 0 );
 		}
 	}
+#if defined(INFO) || !defined(NDEBUG)
+	printf("HostList::AddHost secondely NIC check OK.\n" );
+	printf("HostList::AddHost NIC's broadcast or network IP address checking now.\n" );
+	fflush(stdout);
+#endif
 	//IPɥ쥹NICΥ֥ɥ㥹ȡͥåȥΥɥ쥹Ȱפ̵롣ʤ֤󤢤ꤨʤɡ
 	for( unsigned int i = 0; i < nics.size(); i++ ){
 #if defined(INFO) || !defined(NDEBUG)
-		printf("AddHost ADDR CHECK IpAddress=%s net=%s broad=%s\n", host.IpAddress().c_str(), nics[i].NetworkAddress().c_str(), nics[i].BroadcastAddress().c_str() );fflush(stdout);
+		printf("HostList::AddHost now host checking IpAddress=%s Network%s Broadcast=%s\n",
+						host.IpAddress().c_str(),
+						nics[i].NetworkAddress().c_str(),
+						nics[i].BroadcastAddress().c_str() );
+		fflush(stdout);
 #endif
-		if ( host.IpAddress() == nics[i].NetworkAddress() ||
-			 host.IpAddress() == nics[i].BroadcastAddress() ){
+		if ( host.IpAddress() == nics[i].NetworkAddress() ) {
 #if defined(INFO) || !defined(NDEBUG)
-			printf("AddHost ADDR MATCH\n" );fflush(stdout);
+			printf("HostList::AddHost Host Ip Address is match NIC Network Address.\nIgnore this IP Address\n" );
+			fflush(stdout);
+#endif
+			Unlock( "HostList::AddHost()" );
+			IPMSG_FUNC_RETURN( 0 );
+		}
+		if ( host.IpAddress() == nics[i].BroadcastAddress() ){
+#if defined(INFO) || !defined(NDEBUG)
+			printf("HostList::AddHost Host Ip Address is match NIC Broadcast Address.\nIgnore this IP Address\n" );
+			fflush(stdout);
 #endif
 			Unlock( "HostList::AddHost()" );
 			IPMSG_FUNC_RETURN( 0 );
 		}
 	}
 #if defined(INFO) || !defined(NDEBUG)
-	printf("AddHost HOST CHECK IpAddress=%s addr=%s\n", host.IpAddress().c_str(), nics[0].IpAddress().c_str() );fflush(stdout);
-	printf("AddHost HOST CHECK HostName=%s localhost=%s\n", host.HostName().c_str(), localhostName.c_str() );fflush(stdout);
+	printf("HostList::AddHost NIC's broadcast or network IP address check OK.\n" );
+
+	printf("HostList::AddHost Host IpAddress=[%s] NIC[0] IP Address=[%s]\n", host.IpAddress().c_str(), nics[0].IpAddress().c_str() );
+	printf("HostList::AddHost HostName=[%s] LocalhostName=[%s]\n", host.HostName().c_str(), localhostName.c_str() );
+	fflush(stdout);
 #endif
 	//IPɥ쥹롼ץХåɥ쥹Ȱפ̵롣
 	if ( host.IpAddress() == "127.0.0.1" || host.IpAddress() == "::1" ){
 #if defined(INFO) || !defined(NDEBUG)
-		printf("IGNORE HOST.Because host IpAddress local loopback.\n" );fflush(stdout);
+		printf("HostList::AddHost Ignore this host item.Because host IP Address is local loopback.\n" );
+		fflush(stdout);
 #endif
 		Unlock( "HostList::AddHost()" );
 		IPMSG_FUNC_RETURN( 0 );
@@ -286,32 +324,71 @@ HostList::AddHost( const HostListItem& host, bool isPermitSameHardwareAddress )
 	//IPɥ쥹NICIPɥ쥹ȰפΤ˥ۥ̾Ȱפʤ̵롣
 	if ( host.IpAddress() == nics[0].IpAddress() && host.HostName() != localhostName ){
 #if defined(INFO) || !defined(NDEBUG)
-		printf("MATCH IPADDRESS but not same hostname.\n" );fflush(stdout);
+		printf("HostList::AddHost Ignore this host item.Because host IPAddress and NIC[0]'s IP Address is match,but not same hostname.\n" );
+		fflush(stdout);
 #endif
 		Unlock( "HostList::AddHost()" );
 		IPMSG_FUNC_RETURN( 0 );
 	}
+	//ƱۥȤۥȥꥹȤ¸ߤ뤫Ĵ٤롣
 	std::vector<HostListItem>::iterator tmpHost;
-	for( tmpHost = items.begin(); tmpHost != items.end(); tmpHost++ ){
-		if ( isPermitSameHardwareAddress ) {
+	if ( isPermitSameHardwareAddress ) {
+		//Ʊϡɥɥ쥹¸ߤ硣
+		for( tmpHost = items.begin(); tmpHost != items.end(); tmpHost++ ){
+			//ƱIPɥ쥹Ĥä
 			if ( tmpHost->Equals( host ) ) {
 				is_found = true;
 				break;
 			}
-		} else {
+		}
+	} else {
+		//Ʊϡɥɥ쥹¸ߤʤ硣
+		for( tmpHost = items.begin(); tmpHost != items.end(); tmpHost++ ){
+			//ƱIPɥ쥹Ĥä̵뤷ޤ
+			if ( tmpHost->Equals( host ) ) {
+				//ϡɥɥ쥹ǤʤΤ˰פʤ
+				if ( host.HardwareAddress() != NULL_HARDWARE_ADDRESS && !tmpHost->EqualsHardwareAddress( host ) ) {
+					//ٹå¥
+					printf("Duplicate IP Address detected. IP Address [%s] was assgined to MAC Address [%s],[%s]\n",
+							host.IpAddress().c_str(),
+							host.HardwareAddress().c_str(),
+							tmpHost->HardwareAddress().c_str() );
+				}
+				//ʥۥȤϿƤΤؤ롣
+				if ( host.HardwareAddress() != NULL_HARDWARE_ADDRESS && tmpHost->HardwareAddress() == NULL_HARDWARE_ADDRESS ) {
 #if defined(INFO) || !defined(NDEBUG)
-		printf("SEARCHING HARDWARE ADDRESS...base[%s] check[%s]\n", host.HardwareAddress().c_str(), tmpHost->HardwareAddress().c_str() );fflush(stdout);
+					printf("HostList::AddHost Storange host was entried....host list item[%s] host[%s]\n",
+									tmpHost->HardwareAddress().c_str(),
+									host.HardwareAddress().c_str() );
+					fflush(stdout);
 #endif
+					*tmpHost = host;
+				}
+				is_found = true;
+				break;
+			}
+#if defined(INFO) || !defined(NDEBUG)
+			printf("HostList::AddHost Searching hardware address...host[%s] host list item[%s]\n",
+							host.HardwareAddress().c_str(),
+							tmpHost->HardwareAddress().c_str() );
+			fflush(stdout);
+#endif
+			//㤦IPɥ쥹ǥϡɥɥ쥹פ̵뤹ΤפۥȥꥹȤǤIPv4ǡΥۥȤIPv6ʤ顣
 			if ( tmpHost->EqualsHardwareAddress( host ) ) {
 #if defined(INFO) || !defined(NDEBUG)
-		printf("FOUND ADDRESS %s\n", host.HardwareAddress().c_str() );fflush(stdout);
+				printf("HostList::AddHost Found same hardware address in this host list.(HWADDR %s)\n", host.HardwareAddress().c_str() );
+				fflush(stdout);
 #endif
 				is_found = true;
-				//IPv6IPv4ͥ褹롣
+				//IPv6IPv4ͥ褹롣ʸĤäȤˤ뤱IPv6ΥۥȤִ
+#if defined(INFO) || !defined(NDEBUG)
+				printf("HostList::AddHost host.AddressFamily() %s %s\n", host.IpAddress().c_str(), host.AddressFamily() == AF_INET6 ? "AF_INET6" : "AF_INET" );
+				printf("HostList::AddHost tmpHost.AddressFamily() %s %s\n", tmpHost->IpAddress().c_str(), tmpHost->AddressFamily() == AF_INET6 ? "AF_INET6" : "AF_INET" );
+#endif
 				if ( host.AddressFamily() == AF_INET6 && tmpHost->AddressFamily() == AF_INET ) {
 					*tmpHost = host;
 #if defined(INFO) || !defined(NDEBUG)
-		printf("ͥ褵ޤ%s\n", host.HardwareAddress().c_str() );fflush(stdout);
+					printf("HostList::AddHost Host is IPv6 supported,So swaped same hardware address in host list that is supported IPv4[%s].\n", host.HardwareAddress().c_str() );fflush(stdout);
 #endif
 				}
 				break;
@@ -321,11 +398,17 @@ HostList::AddHost( const HostListItem& host, bool isPermitSameHardwareAddress )
 	int ret = 0;
 	if ( !is_found ) {
 #if defined(INFO) || !defined(NDEBUG)
-		printf("AddHost Nickname=%s\n", host.Nickname().c_str() );fflush(stdout);
-		printf("AddHost GroupName=%s\n", host.GroupName().c_str() );fflush(stdout);
+		printf("HostList::AddHost Nickname=[%s] GroupName=[%s]\n", host.Nickname().c_str(), host.GroupName().c_str() );
+		fflush(stdout);
 #endif
 		items.push_back( host );
 		ret = 1;
+	} else {
+#if defined(INFO) || !defined(NDEBUG)
+		printf("HostList::AddHost Host(%s[%s]) was not found.Nickname=[%s] GroupName=[%s]\n",
+					host.IpAddress().c_str(), host.HardwareAddress().c_str(), host.Nickname().c_str(), host.GroupName().c_str() );
+		fflush(stdout);
+#endif
 	}
 	if ( agent->GetSortHostListComparator() != NULL ){
 		if ( items.size() > 0 ) {
@@ -461,9 +544,6 @@ HostList::CreateHostListItemFromPacket( const Packet& packet )
 	ret.setUserName( packet.UserName() );
 	ret.setCommandNo( packet.CommandMode() | packet.CommandOption() );
 	ret.setIpAddress( getSockAddrInRawAddress( packet.Addr() ) );
-#if defined(INFO) || !defined(NDEBUG)
-	printf( "CreateHostListItemFromPacket port %d\n", ntohs( getSockAddrInPortNo( packet.Addr() ) ) );fflush(stdout);
-#endif
 	ret.setPortNo( ntohs( getSockAddrInPortNo( packet.Addr() ) ) );
 	unsigned int loc = packet.Option().find_first_of( '\0' );
 	if ( loc == std::string::npos ) {
@@ -487,30 +567,13 @@ HostList::FindHostByHostName( std::string hostName, int addressFamily )
 	IPMSG_FUNC_ENTER( "std::vector<HostListItem>::iterator HostList::FindHostByHostName( std::string hostName )" );
 	Lock( "HostList::FindHostByHostName()" );
 	std::vector<HostListItem>::iterator ret = end();
-//	printf( "HostName [%s]\n", hostName.c_str() );fflush(stdout);
-//	printf( "HostList.size [%d]\n", items.size() );fflush(stdout);
 
-#if defined(DEBUG)
-	bool isMatch = false;
-#endif
 	for( std::vector<HostListItem>::iterator ix = begin(); ix < end(); ix++ ){
-#if defined(INFO) || !defined(NDEBUG)
-		printf( "ix->HostName [%s]\n", ix->HostName().c_str() );fflush(stdout);
-#endif
 		if ( ix->HostName() == hostName && addressFamily == ix->AddressFamily() ) {
-#if defined(DEBUG)
-			printf("HOSTNAME MATCH!!!\n");fflush(stdout);
-			isMatch = true;
-#endif
 			ret = ix;
 			break;
 		}
 	}
-#if defined(DEBUG)
-	if ( !isMatch ){
-		printf("HOSTNAME UNMATCH!!!\n");fflush(stdout);
-	}
-#endif
 	Unlock( "HostList::FindHostByHostName()" );
 	IPMSG_FUNC_RETURN( ret );
 }
@@ -531,24 +594,15 @@ HostList::FindHostByAddress( std::string addr )
 		IPMSG_FUNC_RETURN( ret );
 	}
 	for( std::vector<HostListItem>::iterator ix = begin(); ix < end(); ix++ ){
-#if defined(DEBUG)
-		printf("HOST CHECK IpAddress=%s addr=%s\n", ix->IpAddress().c_str(), addr.c_str() );fflush(stdout);
-#endif
 		struct sockaddr_storage ixss;
 		if ( createSockAddrIn( &ixss, ix->IpAddress(), 0 ) == NULL ){
 			IPMSG_FUNC_RETURN( ret );
 		}
 		if ( isSameSockAddrIn( ss, ixss ) ){
-#if defined(DEBUG)
-			printf("HOST FOUND!!!\n");fflush(stdout);
-#endif
 			ret = ix;
 			break;
 		}
 	}
-#if defined(DEBUG)
-	printf("HOST NOT FOUND!!!\n");fflush(stdout);
-#endif
 	Unlock( "HostList::FindHostByAddress()" );
 	IPMSG_FUNC_RETURN( ret );
 }
@@ -663,7 +717,7 @@ HostListItem::Compare( const HostListItem& item ) const
 		 item.IpAddress() > IpAddress() ){
 		IPMSG_FUNC_RETURN( 1 );
 	}
-	IPMSG_FUNC_RETURN(  -1 );
+	IPMSG_FUNC_RETURN( -1 );
 }
 
 /**
@@ -683,7 +737,7 @@ HostListItem::CompareHardwareAddress( const HostListItem& item ) const
 	if ( item.HardwareAddress() > HardwareAddress() ){
 		IPMSG_FUNC_RETURN( 1 );
 	}
-	IPMSG_FUNC_RETURN(  -1 );
+	IPMSG_FUNC_RETURN( -1 );
 }
 
 /**
@@ -696,26 +750,17 @@ HostList::qsort( HostListComparator *comparator, int left, int right )
 	IPMSG_FUNC_ENTER( "void HostList::qsort( HostListComparator *comparator, int left, int right )" );
 	//ϰϤγϡλ
 	int i = left, j = right;
-#if defined(INFO) || !defined(NDEBUG)
-	printf("ADDRESS LEFT(%d)  =IpAddress=%s\n", left, (items.begin() + left)->IpAddress().c_str() );fflush(stdout);
-	printf("ADDRESS RIGHT(%d) =IpAddress=%s\n", right, (items.begin() + right)->IpAddress().c_str() );fflush(stdout);
-#endif
+
 	//
 	std::vector<HostListItem>::iterator pivot = items.begin() + ( ( left + right ) / 2 );
 	//å
 	while( true ){
 		while( comparator->compare( items.begin() + i, pivot ) < 0 ) i++;
 		while( comparator->compare( pivot, items.begin() + j ) < 0 ) j--;
-		if ( i >= j ) break;
-#if defined(INFO) || !defined(NDEBUG)
-			printf("SWAP BEFORE I(%d)  =IpAddress=%s\n", i, (items.begin() + i)->IpAddress().c_str() );fflush(stdout);
-			printf("SWAP BEFORE J(%d) =IpAddress=%s\n", j, (items.begin() + j)->IpAddress().c_str() );fflush(stdout);
-#endif
-			std::iter_swap( items.begin() + i, items.begin() + j );
-#if defined(INFO) || !defined(NDEBUG)
-		printf("SWAP BEFORE I(%d) =IpAddress=%s\n", i, (items.begin() + i)->IpAddress().c_str() );fflush(stdout);
-		printf("SWAP BEFORE J(%d) =IpAddress=%s\n", j, (items.begin() + j)->IpAddress().c_str() );fflush(stdout);
-#endif
+		if ( i >= j ) {
+			break;
+		}
+		std::iter_swap( items.begin() + i, items.begin() + j );
 		i++;
 		j--;
 	}
