@@ -44,6 +44,7 @@ const int IPMSG_DEFAULT_PORT=0x0979;
 
 namespace ipmsg {
 
+extern "C" void *ProcessPacketThread( void *param );
 extern "C" void *GetFileDataThread( void *param );
 extern "C" void *GetDirFilesThread( void *param );
 
@@ -68,6 +69,7 @@ class IpMessengerAgentImpl {
 
 		IPMSG_READONLY_PROPERTY( std::string, LoginName );
 		IPMSG_READONLY_PROPERTY( std::string, HostName );
+		IPMSG_READONLY_PROPERTY( bool, IsNetworkStarted );
 		IPMSG_PROPERTY( bool, IsDialup );
 		IPMSG_PROPERTY( bool, UseIPv6 );
 		IPMSG_PROPERTY( bool, AbortDownloadAtFileChanged );
@@ -86,9 +88,9 @@ class IpMessengerAgentImpl {
 		void Logout();
 		HostList& GetHostList();
 		HostList& UpdateHostList( bool isRetry=false );
-		bool SendMsg( HostListItem host, std::string msg, bool isSecret, bool isLockPassword=false, int hostCountAtSameTime=1, bool noLogging=false, unsigned long opt=0UL );
-		bool SendMsg( HostListItem host, std::string msg, bool isSecret, AttachFile& file, bool isLockPassword=false, int hostCountAtSameTime=1, bool noLogging=false, unsigned long opt=0UL );
-		bool SendMsg( HostListItem host, std::string msg, bool isSecret, AttachFileList& files, bool isLockPassword=false, int hostCountAtSameTime=1, bool noLogging=false, unsigned long opt=0UL, bool isRetry = false, unsigned long PrevPacketNo = 0UL );
+		bool SendMsg( HostListItem host, std::string msg, const Secret &isSecret, const LockPassword &isLockPassword=LockPassword::Off(), int hostCountAtSameTime=1, const Logging &isLogging=Logging::On(), unsigned long opt=0UL );
+		bool SendMsg( HostListItem host, std::string msg, const Secret &isSecret, AttachFile& file, const LockPassword &isLockPassword=LockPassword::Off(), int hostCountAtSameTime=1, const Logging &isLogging=Logging::On(), unsigned long opt=0UL );
+		bool SendMsg( HostListItem host, std::string msg, const Secret &isSecret, AttachFileList& files, const LockPassword &isLockPassword=LockPassword::Off(), int hostCountAtSameTime=1, const Logging &isLogging=Logging::On(), unsigned long opt=0UL, bool isRetry = false, unsigned long PrevPacketNo = 0UL );
 		void ResetAbsence();
 		void SetAbsence( std::string encoding, std::vector<AbsenceMode> absenceModes );
 		std::vector<GroupItem> GetGroupList();
@@ -131,7 +133,6 @@ class IpMessengerAgentImpl {
 		SentMessageList sentMsgList;
 		RecievedMessageList recvMsgList;
 		bool _IsAbsence;
-		bool networkStarted;
 		FileNameConverter *converter;
 		std::vector<AbsenceMode> absenceModeList;
 		std::string DecryptErrorMessage;
@@ -140,7 +141,6 @@ class IpMessengerAgentImpl {
 		std::string HostAddress;
 
 		std::map<int, NetworkInterface> sd_addr;
-		std::map<int, bool> sd_is_broadcast;
 		std::map<int, bool> sd_address_family;
 		std::vector<int> tcp_sd;
 		std::vector<int> udp_sd;
@@ -168,7 +168,7 @@ class IpMessengerAgentImpl {
 		void InitRecv( const std::vector<NetworkInterface>& nics );
 		int InitUdpRecv( struct sockaddr_storage addr, const char *devname );
 		int InitTcpRecv( struct sockaddr_storage addr, const char *devname );
-		int RecvPacket();
+		int RecvPacket( bool isBlock );
 		bool RecvUdp( fd_set *fds, struct sockaddr_storage *sender_addr, int *sz, char *buf, int *udp_socket );
 		bool RecvTcp( fd_set *fds, struct sockaddr_storage *sender_addr, int *sz, char *buf, int *tcp_socket );
 		bool FindDuplicatePacket( const Packet &packet );
