@@ -69,7 +69,7 @@ ipmsg::IpMsgPrintBuf( const char* bufname, const char *buf, const int size )
 	int continue_count = 0;
 	unsigned char pchar = *buf;
 	bool can_not_print = true;
-	printf("%s(%d bytes)[", bufname, size);fflush(stdout);
+	printf("ipmsg::IpMsgPrintBuf %s(%d bytes)[", bufname, size);fflush(stdout);
 	for( int i = 0; i < size; i++ ){
 		if ( !isprint( buf[i] ) && buf[i] != 0x20 ) {
 			if ( pchar != buf[i] ){
@@ -141,18 +141,18 @@ ipmsg::GetCommandString( unsigned long cmd )
  */
 void
 ipmsg::IpMsgDumpPacket( ipmsg::Packet packet, struct sockaddr_storage *sender_addr ){
-	printf( ">> R E C V >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n");fflush(stdout);
-	printf( "send from \n" );
+	printf( "ipmsg::IpMsgDumpPacket == RECV PACKET DUMP START ============================>>\n");fflush(stdout);
+	printf( "ipmsg::IpMsgDumpPacket send from \n" );
 	IpMsgDumpAddr( sender_addr );
-	//printf( "send from %s(%d)\n", getSockAddrInRawAddress( sender_addr ).c_str(), ntohs( getSockAddrInPortNo( sender_addr ) ) );fflush(stdout);
-	printf( "VersionNo    [%ld]\n", packet.VersionNo() );fflush(stdout);
-	printf( "PacketNo     [%ld]\n", packet.PacketNo() );fflush(stdout);
-	printf( "CommandMode  [%ld][%s]\n", packet.CommandMode(), ipmsg::GetCommandString( packet.CommandMode() ).c_str() );fflush(stdout);
-	printf( "CommandOption[%ld]\n", packet.CommandOption() );fflush(stdout);
-	printf( "HostName     [%s]\n", packet.HostName().c_str() );fflush(stdout);
-	printf( "UserName     [%s]\n", packet.UserName().c_str() );fflush(stdout);
-	IpMsgPrintBuf("Option", packet.Option().c_str(), packet.Option().length() );
-	printf( "<< R E C V <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n\n\n");fflush(stdout);
+	//printf( "ipmsg::IpMsgDumpPacket send from %s(%d)\n", getSockAddrInRawAddress( sender_addr ).c_str(), ntohs( getSockAddrInPortNo( sender_addr ) ) );fflush(stdout);
+	printf( "ipmsg::IpMsgDumpPacket VersionNo    [%ld]\n", packet.VersionNo() );fflush(stdout);
+	printf( "ipmsg::IpMsgDumpPacket PacketNo     [%ld]\n", packet.PacketNo() );fflush(stdout);
+	printf( "ipmsg::IpMsgDumpPacket CommandMode  [%ld][%s]\n", packet.CommandMode(), ipmsg::GetCommandString( packet.CommandMode() ).c_str() );fflush(stdout);
+	printf( "ipmsg::IpMsgDumpPacket CommandOption[%ld]\n", packet.CommandOption() );fflush(stdout);
+	printf( "ipmsg::IpMsgDumpPacket HostName     [%s]\n", packet.HostName().c_str() );fflush(stdout);
+	printf( "ipmsg::IpMsgDumpPacket UserName     [%s]\n", packet.UserName().c_str() );fflush(stdout);
+	IpMsgPrintBuf("ipmsg::IpMsgDumpPacket Option", packet.Option().c_str(), packet.Option().length() );
+	printf( "ipmsg::IpMsgDumpPacket << RECV PACKET DUMP END =============================\n\n");fflush(stdout);
 }
 
 /**
@@ -168,23 +168,23 @@ ipmsg::IpMsgDumpHostList( const char *s, ipmsg::HostList& hostList )
 
 	memcpy( head+2, s, strlen( s ) );
 	memcpy( foot+2, s, strlen( s ) );
-	printf("\n\n");fflush(stdout);
-	printf("%s", head );fflush(stdout);
+	printf( "\n\n" );fflush(stdout);
+	printf( "ipmsg::IpMsgDumpHostList %s", head );fflush(stdout);
 	for( std::vector<ipmsg::HostListItem>::iterator ix = hostList.begin(); ix != hostList.end(); ix++ ){
-		printf( "Version[%s]\n" \
-				"AbsenceDescription[%s]\n" \
-				"User[%s]\n" \
-				"Host[%s]\n" \
-				"CommandNo[%lu]\n" \
-				"IpAddress[%s]\n" \
-				"NickName[%s]\n" \
-				"Group[%s]\n" \
-				"Encoding[%s]\n" \
-				"EncryptionCapacity[%lu]\n" \
-				"PubKeyHex[%s]\n" \
-				"EncryptMethodHex[%s]\n" \
-				"PortNo[%lu]\n" \
-				"##########################################################\n",
+		printf( "ipmsg::IpMsgDumpHostList Version[%s]\n" \
+				"ipmsg::IpMsgDumpHostList AbsenceDescription[%s]\n" \
+				"ipmsg::IpMsgDumpHostList User[%s]\n" \
+				"ipmsg::IpMsgDumpHostList Host[%s]\n" \
+				"ipmsg::IpMsgDumpHostList CommandNo[%lu]\n" \
+				"ipmsg::IpMsgDumpHostList IpAddress[%s]\n" \
+				"ipmsg::IpMsgDumpHostList NickName[%s]\n" \
+				"ipmsg::IpMsgDumpHostList Group[%s]\n" \
+				"ipmsg::IpMsgDumpHostList Encoding[%s]\n" \
+				"ipmsg::IpMsgDumpHostList EncryptionCapacity[%lu]\n" \
+				"ipmsg::IpMsgDumpHostList PubKeyHex[%s]\n" \
+				"ipmsg::IpMsgDumpHostList EncryptMethodHex[%s]\n" \
+				"ipmsg::IpMsgDumpHostList PortNo[%lu]\n" \
+				"ipmsg::IpMsgDumpHostList ##########################################################\n",
 				ix->Version().c_str(),
 				ix->AbsenceDescription().c_str(),
 				ix->UserName().c_str(),
@@ -199,7 +199,7 @@ ipmsg::IpMsgDumpHostList( const char *s, ipmsg::HostList& hostList )
 				ix->EncryptMethodHex().c_str(),
 				ix->PortNo() );fflush(stdout);
 	}
-	printf("%s", foot );fflush(stdout);
+	printf( "ipmsg::IpMsgDumpHostList %s", foot );fflush(stdout);
 }
 void
 ipmsg::IpMsgDumpAddr( const struct sockaddr_storage *addr )
@@ -207,25 +207,27 @@ ipmsg::IpMsgDumpAddr( const struct sockaddr_storage *addr )
 #ifdef ENABLE_IPV4
 	if ( addr->ss_family == AF_INET ) {
 		const struct sockaddr_in *sin = ( const struct sockaddr_in *)addr;
-		printf( "THIS IS AF_INET addr\n" );
-		printf( "  IP   =%s\n", getSockAddrInRawAddress( addr ).c_str() );
-		printf( "  PORT =%d\n", ntohs( sin->sin_port ) );
+		printf( "ipmsg::IpMsgDumpAddr AF_INET" );
+		printf( " IP=[%s]", getSockAddrInRawAddress( addr ).c_str() );
+		printf( " PORT=(%d)", ntohs( sin->sin_port ) );
 #ifdef BSD
-		printf( "  LEN  =%d\n", sin->sin_len );
+		printf( " LEN=%d", sin->sin_len );
 #endif
+		printf( "\n" );
 		fflush( stdout );
 	}
 #endif
 #ifdef ENABLE_IPV6
 	if ( addr->ss_family == AF_INET6 ) {
 		const struct sockaddr_in6 *sin6 = ( const struct sockaddr_in6 *)addr;
-		printf( "THIS IS AF_INET6 addr\n" );
-		printf( "  IP   =%s\n", getSockAddrInRawAddress( addr ).c_str() );
-		printf( "  PORT =%d\n", ntohs( sin6->sin6_port ) );
+		printf( "ipmsg::IpMsgDumpAddr AF_INET6" );
+		printf( " IP=[%s]", getSockAddrInRawAddress( addr ).c_str() );
+		printf( " PORT=(%d)", ntohs( sin6->sin6_port ) );
 #ifdef SIN6_LEN
-		printf( "  LEN  =%d\n", sin6->sin6_len );
+		printf( " LEN=(%d)", sin6->sin6_len );
 #endif
-		printf( "  SCOPE=%d\n", sin6->sin6_scope_id );
+		printf( " SCOPE=(%d)", sin6->sin6_scope_id );
+		printf( "\n" );
 		fflush( stdout );
 	}
 #endif
@@ -244,11 +246,11 @@ ipmsg::IpMsgMutexInit( const char *pos, pthread_mutex_t *mutex, const pthread_mu
 {
 #ifdef HAVE_PTHREAD
 #if defined(LOCK_DEBUG)
-	printf( "MutexInit before:%s\n", pos );fflush(stdout);
+	printf( "ipmsg::IpMsgMutexInit before:%s\n", pos );fflush(stdout);
 #endif
 	int ret = pthread_mutex_init(mutex, mutexattr);
 #if defined(LOCK_DEBUG)
-	printf( "MutexInit after :%s\n", pos );fflush(stdout);
+	printf( "ipmsg::IpMsgMutexInit after :%s\n", pos );fflush(stdout);
 #endif
 	return ret;
 #else
@@ -267,11 +269,11 @@ ipmsg::IpMsgMutexLock( const char *pos, pthread_mutex_t *mutex )
 {
 #ifdef HAVE_PTHREAD
 #if defined(LOCK_DEBUG)
-	printf( "MutexLock before:%s\n", pos );fflush(stdout);
+	printf( "ipmsg::IpMsgMutexLock before:%s\n", pos );fflush(stdout);
 #endif
 	int ret = pthread_mutex_lock( mutex );
 #if defined(LOCK_DEBUG)
-	printf( "MutexLock after :%s\n", pos );fflush(stdout);
+	printf( "ipmsg::IpMsgMutexLock after :%s\n", pos );fflush(stdout);
 #endif
 	return ret;
 #else
@@ -290,11 +292,11 @@ ipmsg::IpMsgMutexUnlock( const char *pos, pthread_mutex_t *mutex )
 {
 #ifdef HAVE_PTHREAD
 #if defined(LOCK_DEBUG)
-	printf( "MutexUnlock before:%s\n", pos );fflush(stdout);
+	printf( "ipmsg::IpMsgMutexUnlock before:%s\n", pos );fflush(stdout);
 #endif
 	int ret = pthread_mutex_unlock( mutex );
 #if defined(LOCK_DEBUG)
-	printf( "MutexUnlock after :%s\n", pos );fflush(stdout);
+	printf( "ipmsg::IpMsgMutexUnlock after :%s\n", pos );fflush(stdout);
 #endif
 	return ret;
 #else
@@ -313,11 +315,11 @@ ipmsg::IpMsgMutexDestroy( const char *pos, pthread_mutex_t *mutex )
 {
 #ifdef HAVE_PTHREAD
 #if defined(LOCK_DEBUG)
-	printf( "MutexDestroy before:%s\n", pos );fflush(stdout);
+	printf( "ipmsg::IpMsgMutexDestroy before:%s\n", pos );fflush(stdout);
 #endif
 	int ret = pthread_mutex_destroy( mutex );
 #if defined(LOCK_DEBUG)
-	printf( "MutexDestroy after :%s\n", pos );fflush(stdout);
+	printf( "ipmsg::IpMsgMutexDestroy after :%s\n", pos );fflush(stdout);
 #endif
 	return ret;
 #else
